<?php
/**
 * Service options
 *
 * @package Theme Palace
 * @subpackage Yule Pro
 * @since Yule Pro 1.0.0
 */

// Add service section
$wp_customize->add_section( 'yule_pro_service_section', array(
	'title'             => esc_html__( 'Services','yule-pro' ),
	'description'       => esc_html__( 'Services options.', 'yule-pro' ),
	'panel'             => 'yule_pro_front_page_panel',
) );

// service enable control and setting
$wp_customize->add_setting( 'yule_pro_theme_options[service_section_enable]', array(
	'sanitize_callback' => 'yule_pro_sanitize_switch_control',
	'default'          	=> $options['service_section_enable'],
) );

$wp_customize->add_control( new Yule_Pro_Switch_Control( $wp_customize, 'yule_pro_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Services Enable', 'yule-pro' ),
	'section'           => 'yule_pro_service_section',
	'on_off_label' 		=> yule_pro_switch_options(),
) ) );

// service content type control and setting
$wp_customize->add_setting( 'yule_pro_theme_options[service_content_type]', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback' => 'yule_pro_sanitize_select',
) );

$wp_customize->add_control( 'yule_pro_theme_options[service_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'yule-pro' ),
	'section'           => 'yule_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'yule_pro_is_service_section_enable',
	'choices'			=> array( 
		'demo' 		=> esc_html__( 'Demo', 'yule-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'yule-pro' ),
		'page' 		=> esc_html__( 'Page', 'yule-pro' ),
		'post' 		=> esc_html__( 'Post', 'yule-pro' ),
	),
) );

// service content type post setting and control.
$wp_customize->add_setting( 'yule_pro_theme_options[service_content_post]', array(
	'sanitize_callback' => 'yule_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'yule_pro_theme_options[service_content_post]', array(
	'active_callback'	=> 'yule_pro_is_service_section_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'yule-pro' ),
	'description'       => esc_html__( 'Input three post ids you would like to show. Simply hover post title on dashboard to see the Post ID. ie: 11, 24, 34', 'yule-pro' ),
	'section'           => 'yule_pro_service_section',
	'type'				=> 'text',
) );

for ( $i = 1; $i <= 3; $i++ ) {
	// Show page drop-down setting and control
	$wp_customize->add_setting( 'yule_pro_theme_options[service_content_page_' . $i . ']', array(
		'sanitize_callback' => 'yule_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'yule_pro_theme_options[service_content_page_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Select Page %d', 'yule-pro' ), $i ),
		'section'        	=> 'yule_pro_service_section',
		'active_callback' 	=> 'yule_pro_is_service_section_content_page',
		'type'				=> 'dropdown-pages'
	) );

	// Services hr setting and control
	$wp_customize->add_setting( 'yule_pro_theme_options[service_section_hr_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Yule_Pro_Customize_Horizontal_Line( $wp_customize, 'yule_pro_theme_options[service_section_hr_' . $i . ']',
		array(
			'section'         => 'yule_pro_service_section',
			'active_callback' => 'yule_pro_is_service_section_content_custom',
			'type'			  => 'hr'
	) ) );

	// service title setting and control
	$wp_customize->add_setting( 'yule_pro_theme_options[service_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'          	=> $options['service_title'],
	) );

	$wp_customize->add_control( 'yule_pro_theme_options[service_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Service Title %d', 'yule-pro' ), $i ),
		'section'        	=> 'yule_pro_service_section',
		'active_callback' 	=> 'yule_pro_is_service_section_content_custom',
		'type'				=> 'text',
	) );

	// service title setting and control
	$wp_customize->add_setting( 'yule_pro_theme_options[service_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'yule_pro_theme_options[service_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Service Link %d', 'yule-pro' ), $i ),
		'section'        	=> 'yule_pro_service_section',
		'active_callback' 	=> 'yule_pro_is_service_section_content_custom',
		'type'				=> 'url',
	) );

	// service description setting and control
	$wp_customize->add_setting( 'yule_pro_theme_options[service_description_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'          	=> $options['service_description'],
	) );

	$wp_customize->add_control( 'yule_pro_theme_options[service_description_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Service Description %d', 'yule-pro' ), $i ),
		'section'        	=> 'yule_pro_service_section',
		'active_callback' 	=> 'yule_pro_is_service_section_content_custom',
		'type'				=> 'textarea',
	) );
}