<?php
/**
 * Service section
 *
 * @package Theme Palace
 * @subpackage Yule Pro
 * @since Yule Pro 1.0.0
 */
if ( ! function_exists( 'yule_pro_add_service_section' ) ) :
    /**
    * Add service section
    *
    *@since Yule Pro 1.0.0
    */
    function yule_pro_add_service_section() {
    	$options = yule_pro_get_theme_options();
        // Check if service is enabled on frontpage
        $service_enable = apply_filters( 'yule_pro_section_status', true, 'service_section_enable' );

        if ( true !== $service_enable ) {
            return false;
        }
        // Get service section details
        $section_details = array();
        $section_details = apply_filters( 'yule_pro_filter_service_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render service section now.
        yule_pro_render_service_section( $section_details );
    }
endif;
add_action( 'yule_pro_primary_content', 'yule_pro_add_service_section', 30 );

if ( ! function_exists( 'yule_pro_get_service_section_details' ) ) :
    /**
    * service section details.
    *
    * @since Yule Pro 1.0.0
    * @param array $input service section details.
    */
    function yule_pro_get_service_section_details( $input ) {
        $options = yule_pro_get_theme_options();

        // Content type.
        $service_content_type  = $options['service_content_type'];
        $content = array();
        switch ( $service_content_type ) {
            case 'demo':
                $title = array(
                    1 => esc_html__( '24/7 Customer care', 'yule-pro' ),
                    2 => esc_html__( 'Safe Payment', 'yule-pro' ),
                    3 => esc_html__( 'Easy return', 'yule-pro' ),
                    );
                for ( $i = 1; $i <= 3; $i++ ) :
                    $demo['title']      = $title[$i];
                    $demo['excerpt']    = esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit donec dolor neque id viverra eget, dictum a sem.', 'yule-pro' );
                    $demo['url']		= '#';

                    // Push to the main array.
                    array_push( $content, $demo );
                endfor;
            break;

            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= 3; $i++ ) {
                    if ( ! empty( $options['service_content_page_' . $i] ) )
                        $page_ids[] = $options['service_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => 3,
                    'orderby'           => 'post__in',
                    );                   
            break;

            case 'post':
                $post_ids = ! empty( $options['service_content_post'] ) ? $options['service_content_post'] : array();
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => 3,
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );
            break;

             case 'custom':
                for ( $i = 1; $i <= 3; $i++ ) {
                    $custom['title']     = isset( $options['service_title_' . $i] ) ? $options['service_title_' . $i] : $options['service_title'];
                    $custom['url']       = ! empty( $options['service_link_' . $i] ) ? $options['service_link_' . $i] : '#.';
                    $custom['excerpt']   = isset( $options['service_description_' . $i] ) ? $options['service_description_' . $i] : $options['service_description'];
                   
                    // Push to the main array.
                    array_push( $content, $custom );
                }
            break;

            default:
            break;
        }

        if ( in_array( $service_content_type, array( 'page', 'post', 'product' ) ) ) {

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = yule_pro_trim_content( 17 );
                    $page_post['url']   	= get_the_permalink();

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

        }
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// service section content details.
add_filter( 'yule_pro_filter_service_section_details', 'yule_pro_get_service_section_details' );


if ( ! function_exists( 'yule_pro_render_service_section' ) ) :
  /**
   * Start service section
   *
   * @return string service content
   * @since Yule Pro 1.0.0
   *
   */
   function yule_pro_render_service_section( $content_details = array() ) {
        $i = 1;

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="our-services" class="relative page-section">
            <div class="wrapper">
                <!-- supports col-2,col-3,col-4  -->
                <div class="section-content col-3">
                    <?php foreach ( $content_details as $content ) : ?>
                        <article id="services-01" class="hentry">
                            <div class="service-count"><?php printf( esc_html( '0%d' ), $i ); ?></div><!-- .service-count -->
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>
                            <div class="entry-content">
                                <?php echo wp_kses_post( $content['excerpt'] ); ?>
                            </div><!-- .entry-content -->
                        </article><!-- .hentry -->
                        <?php $i++; 
                    endforeach; ?>
                </div><!-- .entry-content -->
            </div><!-- .wrapper -->
        </div><!-- #our-services-->
    <?php }
endif;